##  Sharing Template Previews by URL
Use a shared URL when you want others to see a live, always up-to-date preview of a diagram template. Anyone with view access to the template, and to the selected fact sheet, can open the link.
You can choose whether to share:
  * The template preview without a selected fact sheet: Recipients open the template and select their own fact sheet as context.
  * The template preview with a selected fact sheet: Recipients open the template directly in the context you chose.


  1. Go to Diagram Templates.
  2. Open a template.
  3. To predefine the context for recipients, select one or more fact sheets from the drop-down list.
You can skip this step if you want recipients to select their own fact sheet.
  4. Copy the URL from your browser.
  5. Share the URL with your stakeholders.


Recipients can explore the preview as long as they have view access. If they need to document or annotate what they see, they can create a static diagram from the preview using Save as Diagram.
